require 'flypbook/version'
require 'capybara'

require 'flypbook/photo_store'
require 'flypbook/google_drive'

module Flypbook
  module DriverExtensions
    def visit(path)
      PhotoStore.take_screenshot 'visit-before'
      super(path)
      PhotoStore.take_screenshot 'visit-after'
    end
  end

  module CapybaraSeleniumNodeExtensions
    def click
      PhotoStore.take_screenshot 'click'
      super
    end
  end

  class Capybara::Selenium::Driver
    prepend DriverExtensions
  end

  class Capybara::Selenium::Node
    prepend CapybaraSeleniumNodeExtensions
  end

  RSpec.configure do |config|
    config.after do
      PhotoStore.take_screenshot 'after' unless ENV['FLYPBOOK_SPEC'] == 'testing'
    end

    config.after(:suite) do
      unless ENV['FLYPBOOK_SPEC'] == 'testing'
        GoogleDrive.new(ENV['GOOGLE_CLIENT_ID'], ENV['GOOGLE_CLIENT_SECRET'], ENV['GOOGLE_REFRESH_TOKEN']).upload
      end
    end
  end
end
